@@ -7,11 +7,11 @@ import (
 	"syscall"
 )
 
-func procAttrForSpawn() *os.ProcAttr {
+func procAttrForSpawn(files []*os.File) *os.ProcAttr {
 	return &os.ProcAttr{
-		Dir:   "/",        // cd to /
-		Env:   []string{}, // empty environment
-		Files: []*os.File{os.Stdin, os.Stdout, os.Stderr},
+		Dir:   "/",
+		Env:   []string{},
+		Files: files,
 		Sys: &syscall.SysProcAttr{
 			Setsid: true, // detach from current terminal
 		},
