@@ -15,11 +15,11 @@ const (
 	daemonCreationFlags = CREATE_BREAKAWAY_FROM_JOB | CREATE_NEW_PROCESS_GROUP | DETACHED_PROCESS
 )
 
-func procAttrForSpawn() *os.ProcAttr {
+func procAttrForSpawn(files []*os.File) *os.ProcAttr {
 	return &os.ProcAttr{
 		Dir:   `C:\`,
 		Env:   []string{"SystemRoot=" + os.Getenv("SystemRoot")}, // SystemRoot is needed for net.Listen for some reason
-		Files: []*os.File{os.Stdin, os.Stdout, os.Stderr},
+		Files: files,
 		Sys:   &syscall.SysProcAttr{CreationFlags: daemonCreationFlags},
 	}
 }
