@@ -105,7 +105,7 @@ func completeIndex(n parse.Node, cfg Config) (*context, []RawItem, error) {
 	ev := cfg.PureEvaler
 	generateForEmpty := func(v interface{}, pos int) (*context, []RawItem, error) {
 		ctx := &context{"index", "", parse.Bareword, range0(pos)}
-		return ctx, generateIndicies(v), nil
+		return ctx, generateIndices(v), nil
 	}
 
 	if is(n, aSep) {
@@ -145,7 +145,7 @@ func completeIndex(n parse.Node, cfg Config) (*context, []RawItem, error) {
 						if indexee := ev.PurelyEvalPrimary(indexing.Head); indexee != nil {
 							ctx := &context{
 								"index", seed, primary.Type, compound.Range()}
-							return ctx, generateIndicies(indexee), nil
+							return ctx, generateIndices(indexee), nil
 						}
 					}
 				}
@@ -185,8 +185,8 @@ func completeVariable(n parse.Node, cfg Config) (*context, []RawItem, error) {
 	if !ok || primary.Type != parse.Variable {
 		return nil, nil, errNoCompletion
 	}
-	sigil, qname := eval.SplitVariableRef(primary.Value)
-	ns, nameSeed := eval.SplitQNameNsIncomplete(qname)
+	sigil, qname := eval.SplitSigil(primary.Value)
+	ns, nameSeed := eval.SplitIncompleteQNameNs(qname)
 	// Move past "$", "@" and "<ns>:".
 	begin := primary.Range().From + 1 + len(sigil) + len(ns)
 
@@ -196,14 +196,14 @@ func completeVariable(n parse.Node, cfg Config) (*context, []RawItem, error) {
 
 	var items []RawItem
 	ev.EachVariableInNs(ns, func(varname string) {
-		items = append(items, noQuoteItem(varname))
+		items = append(items, noQuoteItem(parse.QuoteVariableName(varname)))
 	})
 
 	ev.EachNs(func(thisNs string) {
 		// This is to match namespaces that are "nested" under the current
 		// namespace.
 		if hasProperPrefix(thisNs, ns) {
-			items = append(items, noQuoteItem(thisNs[len(ns):]))
+			items = append(items, noQuoteItem(parse.QuoteVariableName(thisNs[len(ns):])))
 		}
 	})
 
