@@ -7,11 +7,9 @@ package edit
 
 import (
 	"fmt"
-	"os"
 	"sync"
 
 	"github.com/elves/elvish/pkg/cli"
-	"github.com/elves/elvish/pkg/cli/histutil"
 	"github.com/elves/elvish/pkg/eval"
 	"github.com/elves/elvish/pkg/eval/vals"
 	"github.com/elves/elvish/pkg/eval/vars"
@@ -22,7 +20,7 @@ import (
 // Editor is the interface line editor for Elvish.
 type Editor struct {
 	app cli.App
-	ns  eval.Ns
+	ns  *eval.Ns
 
 	excMutex sync.RWMutex
 	excList  vals.List
@@ -40,38 +38,40 @@ type notifier interface {
 func NewEditor(tty cli.TTY, ev *eval.Evaler, st store.Store) *Editor {
 	// Declare the Editor with a nil App first; some initialization functions
 	// require a notifier as an argument, but does not use it immediately.
-	ed := &Editor{ns: eval.Ns{}, excList: vals.EmptyList}
+	ed := &Editor{excList: vals.EmptyList}
+	nb := eval.NsBuilder{}
 	appSpec := cli.AppSpec{TTY: tty}
 
-	fuser, err := histutil.NewFuser(st)
+	hs, err := newHistStore(st)
 	if err != nil {
 		// TODO(xiaq): Report the error.
 	}
 
 	initHighlighter(&appSpec, ev)
-	initMaxHeight(&appSpec, ed.ns)
-	initReadlineHooks(&appSpec, ev, ed.ns)
-	if fuser != nil {
-		initAddCmdFilters(&appSpec, ev, ed.ns, fuser)
-	}
-	initInsertAPI(&appSpec, ed, ev, ed.ns)
-	initPrompts(&appSpec, ed, ev, ed.ns)
+	initMaxHeight(&appSpec, nb)
+	initReadlineHooks(&appSpec, ev, nb)
+	initAddCmdFilters(&appSpec, ev, nb, hs)
+	initInsertAPI(&appSpec, ed, ev, nb)
+	initPrompts(&appSpec, ed, ev, nb)
 	ed.app = cli.NewApp(appSpec)
 
-	initExceptionsAPI(ed)
-	initCommandAPI(ed, ev)
-	initListings(ed, ev, st, fuser)
-	initNavigation(ed, ev)
-	initCompletion(ed, ev)
-	initHistWalk(ed, ev, fuser)
-	initInstant(ed, ev)
-	initMinibuf(ed, ev)
+	initExceptionsAPI(ed, nb)
+	initVarsAPI(ed, nb)
+	initCommandAPI(ed, ev, nb)
+	initListings(ed, ev, st, hs, nb)
+	initNavigation(ed, ev, nb)
+	initCompletion(ed, ev, nb)
+	initHistWalk(ed, ev, hs, nb)
+	initInstant(ed, ev, nb)
+	initMinibuf(ed, ev, nb)
 
-	initBufferBuiltins(ed.app, ed.ns)
-	initTTYBuiltins(ed.app, tty, ed.ns)
-	initMiscBuiltins(ed.app, ed.ns)
-	initStateAPI(ed.app, ed.ns)
-	initStoreAPI(ed.app, ed.ns, fuser)
+	initBufferBuiltins(ed.app, nb)
+	initTTYBuiltins(ed.app, tty, nb)
+	initMiscBuiltins(ed.app, nb)
+	initStateAPI(ed.app, nb)
+	initStoreAPI(ed.app, nb, hs)
+
+	ed.ns = nb.Ns()
 	evalDefaultBinding(ev, ed.ns)
 
 	return ed
@@ -82,29 +82,13 @@ func NewEditor(tty cli.TTY, ev *eval.Evaler, st store.Store) *Editor {
 // A list of exceptions thrown from callbacks such as prompts. Useful for
 // examining tracebacks and other metadata.
 
-func initExceptionsAPI(ed *Editor) {
-	ed.ns.Add("exceptions", vars.FromPtrWithMutex(&ed.excList, &ed.excMutex))
+func initExceptionsAPI(ed *Editor, nb eval.NsBuilder) {
+	nb.Add("exceptions", vars.FromPtrWithMutex(&ed.excList, &ed.excMutex))
 }
 
-func evalDefaultBinding(ev *eval.Evaler, ns eval.Ns) {
-	// TODO(xiaq): The evaler API should accodomate the use case of evaluating a
-	// piece of code in an alternative global namespace.
-
+func evalDefaultBinding(ev *eval.Evaler, ns *eval.Ns) {
 	src := parse.Source{Name: "[default bindings]", Code: defaultBindingsElv}
-	tree, err := parse.Parse(src)
-	if err != nil {
-		panic(err)
-	}
-	op, err := ev.CompileWithGlobal(tree, ns, nil)
-	if err != nil {
-		panic(err)
-	}
-	// TODO(xiaq): Use stdPorts when it is possible to do so.
-	fm := eval.NewTopFrame(ev, src, []*eval.Port{
-		{File: os.Stdin}, {File: os.Stdout}, {File: os.Stderr},
-	})
-	fm.SetLocal(ns)
-	err = fm.Eval(op)
+	err := ev.Eval(src, eval.EvalCfg{Global: ns})
 	if err != nil {
 		panic(err)
 	}
@@ -116,23 +100,21 @@ func (ed *Editor) ReadCode() (string, error) {
 }
 
 // Ns returns a namespace for manipulating the editor from Elvish code.
-func (ed *Editor) Ns() eval.Ns {
+func (ed *Editor) Ns() *eval.Ns {
 	return ed.ns
 }
 
-func (ed *Editor) notify(s string) { ed.app.Notify(s) }
-
 func (ed *Editor) notifyf(format string, args ...interface{}) {
 	ed.app.Notify(fmt.Sprintf(format, args...))
 }
 
 func (ed *Editor) notifyError(ctx string, e error) {
-	if exc, ok := e.(*eval.Exception); ok {
+	if exc, ok := e.(eval.Exception); ok {
 		ed.excMutex.Lock()
 		defer ed.excMutex.Unlock()
 		ed.excList = ed.excList.Cons(exc)
 		ed.notifyf("[%v error] %v\n"+
-			`see stack trace with "use exc; exc:show $edit:exceptions[%d]"`,
+			`see stack trace with "show $edit:exceptions[%d]"`,
 			ctx, e, ed.excList.Len()-1)
 	} else {
 		ed.notifyf("[%v error] %v", ctx, e)
