@@ -1,15 +1,9 @@
 package edit
 
 import (
-	"bufio"
-	"io"
-	"os"
-	"sync"
-
 	"github.com/elves/elvish/pkg/cli"
 	"github.com/elves/elvish/pkg/cli/addons/instant"
 	"github.com/elves/elvish/pkg/eval"
-	"github.com/elves/elvish/pkg/eval/vals"
 	"github.com/elves/elvish/pkg/parse"
 )
 
@@ -26,57 +20,29 @@ import (
 // commands. For example, if you type `sudo rm -rf /tmp/*` in the instant mode,
 // Elvish will attempt to evaluate `sudo rm -rf /` when you typed that far.
 
-func initInstant(ed *Editor, ev *eval.Evaler) {
+func initInstant(ed *Editor, ev *eval.Evaler, nb eval.NsBuilder) {
 	bindingVar := newBindingVar(EmptyBindingMap)
 	binding := newMapBinding(ed, ev, bindingVar)
-	ed.ns.AddNs("-instant",
-		eval.Ns{
+	nb.AddNs("-instant",
+		eval.NsBuilder{
 			"binding": bindingVar,
 		}.AddGoFns("<edit:-instant>:", map[string]interface{}{
 			"start": func() { instantStart(ed.app, ev, binding) },
-		}))
+		}).Ns())
 }
 
 func instantStart(app cli.App, ev *eval.Evaler, binding cli.Handler) {
 	execute := func(code string) ([]string, error) {
-		src := parse.Source{Name: "[instant]", Code: code}
-		op, err := ev.ParseAndCompile(src, nil)
+		outPort, collect, err := eval.StringCapturePort()
 		if err != nil {
 			return nil, err
 		}
-		fm := eval.NewTopFrame(ev, src, []*eval.Port{
-			{File: eval.DevNull},
-			{}, // Will be replaced in CaptureOutput
-			{File: eval.DevNull},
-		})
-		var output []string
-		var outputMutex sync.Mutex
-		addLine := func(line string) {
-			outputMutex.Lock()
-			defer outputMutex.Unlock()
-			output = append(output, line)
-		}
-		valuesCb := func(ch <-chan interface{}) {
-			for v := range ch {
-				addLine("▶ " + vals.ToString(v))
-			}
-		}
-		bytesCb := func(r *os.File) {
-			bufr := bufio.NewReader(r)
-			for {
-				line, err := bufr.ReadString('\n')
-				if err != nil {
-					if err != io.EOF {
-						addLine("i/o error: " + err.Error())
-					}
-					break
-				}
-				addLine(eval.ChopLineEnding(line))
-			}
-		}
-		err = fm.PipeOutput(
-			func(fm *eval.Frame) error { return fm.Eval(op) }, valuesCb, bytesCb)
-		return output, err
+		err = ev.Eval(
+			parse.Source{Name: "[instant]", Code: code},
+			eval.EvalCfg{
+				Ports:     []*eval.Port{nil, outPort},
+				Interrupt: eval.ListenInterrupts})
+		return collect(), err
 	}
 	instant.Start(app, instant.Config{Binding: binding, Execute: execute})
 }
