@@ -6,15 +6,15 @@ import (
 	"github.com/elves/elvish/pkg/parse"
 )
 
-func initMinibuf(ed *Editor, ev *eval.Evaler) {
+func initMinibuf(ed *Editor, ev *eval.Evaler, nb eval.NsBuilder) {
 	bindingVar := newBindingVar(EmptyBindingMap)
 	binding := newMapBinding(ed, ev, bindingVar)
-	ed.ns.AddNs("minibuf",
-		eval.Ns{
+	nb.AddNs("minibuf",
+		eval.NsBuilder{
 			"binding": bindingVar,
 		}.AddGoFns("<edit:minibuf>:", map[string]interface{}{
 			"start": func() { minibufStart(ed, ev, binding) },
-		}))
+		}).Ns())
 }
 
 func minibufStart(ed *Editor, ev *eval.Evaler, binding cli.Handler) {
@@ -38,15 +38,10 @@ func minibufSubmit(ed *Editor, ev *eval.Evaler) {
 	cli.SetAddon(app, nil)
 	code := codeArea.CopyState().Buffer.Content
 	src := parse.Source{Name: "[minibuf]", Code: code}
-	op, err := ev.ParseAndCompile(src, nil)
-	if err != nil {
-		app.Notify(err.Error())
-		return
-	}
 	notifyPort, cleanup := makeNotifyPort(ed)
 	defer cleanup()
-	ports := []*eval.Port{eval.DevNullClosedChan, notifyPort, notifyPort}
-	err = ev.Eval(op, eval.EvalCfg{Ports: ports})
+	ports := []*eval.Port{eval.DummyInputPort, notifyPort, notifyPort}
+	err := ev.Eval(src, eval.EvalCfg{Ports: ports})
 	if err != nil {
 		app.Notify(err.Error())
 	}
