@@ -2,13 +2,12 @@ package eval
 
 import "errors"
 
-var (
-	execFn = notSupportedOnWindows
-	fg     = notSupportedOnWindows
-)
-
 var errNotSupportedOnWindows = errors.New("not supported on Windows")
 
-func notSupportedOnWindows() error {
+func execFn(...interface{}) error {
+	return errNotSupportedOnWindows
+}
+
+func fg(...int) error {
 	return errNotSupportedOnWindows
 }
