@@ -1,16 +1,23 @@
-package eval
+package eval_test
 
 import (
 	"testing"
 
+	. "github.com/elves/elvish/pkg/eval"
+
+	. "github.com/elves/elvish/pkg/eval/evaltest"
 	"github.com/elves/elvish/pkg/eval/vals"
 )
 
-func TestBuiltinFnFlow(t *testing.T) {
+func TestRunParallel(t *testing.T) {
 	Test(t,
 		That(`run-parallel { put lorem } { echo ipsum }`).
 			Puts("lorem").Prints("ipsum\n"),
+	)
+}
 
+func TestEach(t *testing.T) {
+	Test(t,
 		That(`put 1 233 | each $put~`).Puts("1", "233"),
 		That(`echo "1\n233" | each $put~`).Puts("1", "233"),
 		That(`echo "1\r\n233" | each $put~`).Puts("1", "233"),
@@ -18,10 +25,15 @@ func TestBuiltinFnFlow(t *testing.T) {
 		That(`range 10 | each [x]{ if (== $x 4) { break }; put $x }`).
 			Puts(0.0, 1.0, 2.0, 3.0),
 		That(`range 10 | each [x]{ if (== $x 4) { fail haha }; put $x }`).
-			Puts(0.0, 1.0, 2.0, 3.0).ThrowsAny(),
+			Puts(0.0, 1.0, 2.0, 3.0).Throws(AnyError),
 		// TODO(xiaq): Test that "each" does not close the stdin.
-		// TODO: test peach
+	)
+}
 
+// TODO: test peach
+
+func TestFail(t *testing.T) {
+	Test(t,
 		That("fail haha").Throws(FailError{"haha"}, "fail haha"),
 		That("fn f { fail haha }", "fail ?(f)").Throws(
 			FailError{"haha"}, "fail haha ", "f"),
@@ -29,7 +41,12 @@ func TestBuiltinFnFlow(t *testing.T) {
 			FailError{vals.EmptyList}, "fail []"),
 		That("put ?(fail 1)[reason][type]").Puts("fail"),
 		That("put ?(fail 1)[reason][content]").Puts("1"),
+	)
+}
 
-		That(`return`).ThrowsCause(Return),
+func TestReturn(t *testing.T) {
+	Test(t,
+		That("return").Throws(Return),
+		// Use of return inside fn is tested in TestFn
 	)
 }
