@@ -1,17 +1,18 @@
 // +build !windows,!plan9
 
-package eval
+package eval_test
 
 import (
 	"path/filepath"
 	"strings"
 	"testing"
 
-	"github.com/elves/elvish/pkg/util"
+	. "github.com/elves/elvish/pkg/eval/evaltest"
+	"github.com/elves/elvish/pkg/testutil"
 )
 
 func TestCompileEffectUnix(t *testing.T) {
-	_, cleanup := util.InTestDir()
+	_, cleanup := testutil.InTestDir()
 	defer cleanup()
 
 	mustWriteScript("foo", "#!/bin/sh", "echo foo")
@@ -32,6 +33,6 @@ func TestCompileEffectUnix(t *testing.T) {
 }
 
 func mustWriteScript(name string, lines ...string) {
-	mustMkdirAll(filepath.Dir(name))
-	mustWriteFile(name, []byte(strings.Join(lines, "\n")), 0700)
+	testutil.MustMkdirAll(filepath.Dir(name))
+	testutil.MustWriteFile(name, []byte(strings.Join(lines, "\n")), 0700)
 }
