@@ -21,7 +21,7 @@ var reprTests = []struct {
 	{vals.EmptyList, "[]"},
 	{vals.MakeList("bash", false), "[bash $false]"},
 	{vals.EmptyMap, "[&]"},
-	{vals.MakeMap(&Exception{nil, nil}, "elvish"), "[&$ok=elvish]"},
+	{vals.MakeMap(&exception{nil, nil}, "elvish"), "[&$ok=elvish]"},
 	// TODO: test maps of more elements
 }
 
@@ -39,11 +39,11 @@ var stringToSegmentsTests = []struct {
 	want []glob.Segment
 }{
 	{"", []glob.Segment{}},
-	{"a", []glob.Segment{glob.Literal{"a"}}},
-	{"/a", []glob.Segment{glob.Slash{}, glob.Literal{"a"}}},
-	{"a/", []glob.Segment{glob.Literal{"a"}, glob.Slash{}}},
-	{"/a/", []glob.Segment{glob.Slash{}, glob.Literal{"a"}, glob.Slash{}}},
-	{"a//b", []glob.Segment{glob.Literal{"a"}, glob.Slash{}, glob.Literal{"b"}}},
+	{"a", []glob.Segment{glob.Literal{Data: "a"}}},
+	{"/a", []glob.Segment{glob.Slash{}, glob.Literal{Data: "a"}}},
+	{"a/", []glob.Segment{glob.Literal{Data: "a"}, glob.Slash{}}},
+	{"/a/", []glob.Segment{glob.Slash{}, glob.Literal{Data: "a"}, glob.Slash{}}},
+	{"a//b", []glob.Segment{glob.Literal{Data: "a"}, glob.Slash{}, glob.Literal{Data: "b"}}},
 }
 
 func TestStringToSegments(t *testing.T) {
