@@ -18,7 +18,6 @@ import (
 	"unicode"
 
 	"github.com/elves/elvish/pkg/diag"
-	"github.com/elves/elvish/pkg/prog"
 )
 
 // Tree represents a parsed tree.
@@ -27,7 +26,7 @@ type Tree struct {
 	Source Source
 }
 
-// Parse parses the given source. The returned error always has type MultiError
+// Parse parses the given source. The returned error always has type *Error
 // if it is not nil.
 func Parse(src Source) (Tree, error) {
 	return ParseWithDeprecation(src, nil)
@@ -43,7 +42,7 @@ func ParseWithDeprecation(src Source, w io.Writer) (Tree, error) {
 
 // ParseAs parses the given source as a node, depending on the dynamic type of
 // n, writing deprecation warnings to the given io.Writer if it is not nil. If
-// the error is not nil, it always has type MultiError.
+// the error is not nil, it always has type *Error.
 func ParseAs(src Source, n Node, w io.Writer) error {
 	ps := &parser{srcName: src.Name, src: src.Code, warn: w}
 	ps.parse(n)
@@ -53,20 +52,19 @@ func ParseAs(src Source, n Node, w io.Writer) error {
 
 // Errors.
 var (
-	errShouldBeForm         = newError("", "form")
-	errBadLHS               = errors.New("bad assignment LHS")
-	errBadRedirSign         = newError("bad redir sign", "'<'", "'>'", "'>>'", "'<>'")
-	errShouldBeFD           = newError("", "a composite term representing fd")
-	errShouldBeFilename     = newError("", "a composite term representing filename")
-	errShouldBeArray        = newError("", "spaced")
-	errStringUnterminated   = newError("string not terminated")
-	errChainedAssignment    = newError("chained assignment not yet supported")
-	errInvalidEscape        = newError("invalid escape sequence")
-	errInvalidEscapeOct     = newError("invalid escape sequence", "octal digit")
-	errInvalidEscapeHex     = newError("invalid escape sequence", "hex digit")
-	errInvalidEscapeControl = newError("invalid control sequence", "a rune between @ (0x40) and _(0x5F)")
-	errShouldBePrimary      = newError("",
-		"single-quoted string", "double-quoted string", "bareword")
+	errShouldBeForm               = newError("", "form")
+	errBadLHS                     = errors.New("bad assignment LHS")
+	errBadRedirSign               = newError("bad redir sign", "'<'", "'>'", "'>>'", "'<>'")
+	errShouldBeFD                 = newError("", "a composite term representing fd")
+	errShouldBeFilename           = newError("", "a composite term representing filename")
+	errShouldBeArray              = newError("", "spaced")
+	errStringUnterminated         = newError("string not terminated")
+	errChainedAssignment          = newError("chained assignment not yet supported")
+	errInvalidEscape              = newError("invalid escape sequence")
+	errInvalidEscapeOct           = newError("invalid escape sequence", "octal digit")
+	errInvalidEscapeHex           = newError("invalid escape sequence", "hex digit")
+	errInvalidEscapeControl       = newError("invalid control sequence", "a codepoint between 0x3F and 0x5F")
+	errShouldBePrimary            = newError("", "single-quoted string", "double-quoted string", "bareword")
 	errShouldBeVariableName       = newError("", "variable name")
 	errShouldBeRBracket           = newError("", "']'")
 	errShouldBeRBrace             = newError("", "'}'")
@@ -154,11 +152,9 @@ type Form struct {
 	node
 	Assignments []*Assignment
 	Head        *Compound
-	// Left-hand-sides for the spacey assignment. Right-hand-sides are in Args.
-	Vars   []*Compound
-	Args   []*Compound
-	Opts   []*MapPair
-	Redirs []*Redir
+	Args        []*Compound
+	Opts        []*MapPair
+	Redirs      []*Redir
 }
 
 func (fn *Form) parse(ps *parser) {
@@ -197,29 +193,6 @@ func (fn *Form) parse(ps *parser) {
 			if isRedirSign(ps.peek()) {
 				// Redir
 				ps.parse(&Redir{Left: cn}).addTo(&fn.Redirs, fn)
-			} else if cn.sourceText == "=" {
-				// Spacey assignment.
-				// Turn the equal sign into a Sep.
-				addChild(fn, NewSep(ps.src, cn.From, cn.To))
-				// Turn the head and preceding arguments into LHSs.
-				addLHS := func(cn *Compound) {
-					if len(cn.Indexings) == 1 && checkVariableInAssignment(cn.Indexings[0].Head, ps) {
-						fn.Vars = append(fn.Vars, cn)
-					} else {
-						ps.errorp(cn, errBadLHS)
-					}
-				}
-				if fn.Head != nil {
-					addLHS(fn.Head)
-				} else {
-					// TODO(xiaq): Should use the entire assignment form as the range.
-					ps.errorp(cn, errChainedAssignment)
-				}
-				fn.Head = nil
-				for _, cn := range fn.Args {
-					addLHS(cn)
-				}
-				fn.Args = nil
 			} else {
 				parsed{cn}.addTo(&fn.Args, fn)
 			}
@@ -267,7 +240,7 @@ type Assignment struct {
 func (an *Assignment) parse(ps *parser) {
 	ps.parse(&Indexing{ExprCtx: LHSExpr}).addAs(&an.Left, an)
 	head := an.Left.Head
-	if !checkVariableInAssignment(head, ps) {
+	if !ValidLHSVariable(head, true) {
 		ps.errorp(head, errShouldBeVariableName)
 	}
 
@@ -277,27 +250,33 @@ func (an *Assignment) parse(ps *parser) {
 	ps.parse(&Compound{}).addAs(&an.Right, an)
 }
 
-func checkVariableInAssignment(p *Primary, ps *parser) bool {
-	if p.Type == Braced {
+func ValidLHSVariable(p *Primary, allowSigil bool) bool {
+	switch p.Type {
+	case Braced:
 		// TODO(xiaq): check further inside braced expression
 		return true
-	}
-	if p.Type != Bareword && p.Type != SingleQuoted && p.Type != DoubleQuoted {
-		return false
-	}
-	if p.Value == "" {
-		return false
-	}
-	name := p.Value
-	if name[0] == '@' {
-		name = name[1:]
-	}
-	for _, r := range name {
-		if !allowedInVariableName(r) {
+	case SingleQuoted, DoubleQuoted:
+		// Quoted variable names may contain anything
+		return true
+	case Bareword:
+		// Bareword variable names may only contain runes that are valid in raw
+		// variable names
+		if p.Value == "" {
 			return false
 		}
+		name := p.Value
+		if allowSigil && name[0] == '@' {
+			name = name[1:]
+		}
+		for _, r := range name {
+			if !allowedInVariableName(r) {
+				return false
+			}
+		}
+		return true
+	default:
+		return false
 	}
-	return true
 }
 
 // Redir = { Compound } { '<'|'>'|'<>'|'>>' } { Space } ( '&'? Compound )
@@ -407,7 +386,8 @@ func (cn *Compound) parse(ps *parser) {
 func (cn *Compound) tilde(ps *parser) {
 	if ps.peek() == '~' {
 		ps.next()
-		base := node{diag.Ranging{ps.pos - 1, ps.pos}, "~", nil, nil}
+		base := node{Ranging: diag.Ranging{From: ps.pos - 1, To: ps.pos},
+			sourceText: "~", parent: nil, children: nil}
 		pn := &Primary{node: base, Type: Tilde, Value: "~"}
 		in := &Indexing{node: base}
 		parsed{pn}.addAs(&in.Head, in)
@@ -549,6 +529,12 @@ func (pn *Primary) parse(ps *parser) {
 func (pn *Primary) singleQuoted(ps *parser) {
 	pn.Type = SingleQuoted
 	ps.next()
+	pn.singleQuotedInner(ps)
+}
+
+// Parses a single-quoted string after the opening quote. Sets pn.Value but not
+// pn.Type.
+func (pn *Primary) singleQuotedInner(ps *parser) {
 	var buf bytes.Buffer
 	defer func() { pn.Value = buf.String() }()
 	for {
@@ -574,6 +560,12 @@ func (pn *Primary) singleQuoted(ps *parser) {
 func (pn *Primary) doubleQuoted(ps *parser) {
 	pn.Type = DoubleQuoted
 	ps.next()
+	pn.doubleQuotedInner(ps)
+}
+
+// Parses a double-quoted string after the opening quote. Sets pn.Value but not
+// pn.Type.
+func (pn *Primary) doubleQuotedInner(ps *parser) {
 	var buf bytes.Buffer
 	defer func() { pn.Value = buf.String() }()
 	for {
@@ -585,16 +577,19 @@ func (pn *Primary) doubleQuoted(ps *parser) {
 			return
 		case '\\':
 			switch r := ps.next(); r {
-			case 'c', '^':
-				// Control sequence
+			case 'c', '^': // control sequence
 				r := ps.next()
-				if r < 0x40 || r >= 0x60 {
+				if r < 0x3F || r > 0x5F {
 					ps.backup()
 					ps.error(errInvalidEscapeControl)
 					ps.next()
 				}
-				buf.WriteByte(byte(r - 0x40))
-			case 'x', 'u', 'U':
+				if byte(r) == '?' { // special-case: \c? => del
+					buf.WriteByte(byte(0x7F))
+				} else {
+					buf.WriteByte(byte(r - 0x40))
+				}
+			case 'x', 'u', 'U': // two, four, or eight hex digits
 				var n int
 				switch r {
 				case 'x':
@@ -615,8 +610,7 @@ func (pn *Primary) doubleQuoted(ps *parser) {
 					rr = rr*16 + d
 				}
 				buf.WriteRune(rr)
-			case '0', '1', '2', '3', '4', '5', '6', '7':
-				// 2 more octal digits
+			case '0', '1', '2', '3', '4', '5', '6', '7': // three octal digits
 				rr := r - '0'
 				for i := 0; i < 2; i++ {
 					r := ps.next()
@@ -675,16 +669,25 @@ func hexToDigit(r rune) (rune, bool) {
 
 func (pn *Primary) variable(ps *parser) {
 	pn.Type = Variable
-	defer func() { pn.Value = ps.src[pn.From+1 : ps.pos] }()
 	ps.next()
-	// The character of the variable name can be anything.
-	if ps.next() == eof {
+	switch r := ps.next(); r {
+	case eof:
 		ps.backup()
 		ps.error(errShouldBeVariableName)
 		ps.next()
-	}
-	for allowedInVariableName(ps.peek()) {
-		ps.next()
+	case '\'':
+		pn.singleQuotedInner(ps)
+	case '"':
+		pn.doubleQuotedInner(ps)
+	default:
+		defer func() { pn.Value = ps.src[pn.From+1 : ps.pos] }()
+		if !allowedInVariableName(r) && r != '@' {
+			ps.backup()
+			ps.error(errShouldBeVariableName)
+		}
+		for allowedInVariableName(ps.peek()) {
+			ps.next()
+		}
 	}
 }
 
@@ -813,7 +816,7 @@ func (pn *Primary) lbrace(ps *parser) {
 
 	pn.Type = Braced
 
-	// XXX: The compound can be empty, which allows us to parse {,foo}.
+	// TODO(xiaq): The compound can be empty, which allows us to parse {,foo}.
 	// Allowing compounds to be empty can be fragile in other cases.
 	ps.parse(&Compound{ExprCtx: BracedElemExpr}).addTo(&pn.Braced, pn)
 
@@ -849,7 +852,7 @@ func (pn *Primary) bareword(ps *parser) {
 // The following are allowed in barewords:
 //
 // * Anything allowed in variable names
-// * The symbols "./@%+!"
+// * The symbols "./\@%+!"
 // * The symbol "=", if ctx != lhsExpr && ctx != strictExpr
 // * The symbol ",", if ctx != bracedExpr && ctx != strictExpr
 // * The symbols "<>*^", if ctx = commandExpr
@@ -858,7 +861,7 @@ func (pn *Primary) bareword(ps *parser) {
 // Windows.
 func allowedInBareword(r rune, ctx ExprCtx) bool {
 	return allowedInVariableName(r) || r == '.' || r == '/' ||
-		r == '@' || r == '%' || r == '+' || r == '!' ||
+		r == '\\' || r == '@' || r == '%' || r == '+' || r == '!' ||
 		(ctx != LHSExpr && ctx != strictExpr && r == '=') ||
 		(ctx != BracedElemExpr && ctx != strictExpr && r == ',') ||
 		(ctx == CmdExpr && (r == '<' || r == '>' || r == '*' || r == '^'))
@@ -900,7 +903,7 @@ type Sep struct {
 
 // NewSep makes a new Sep.
 func NewSep(src string, begin, end int) *Sep {
-	return &Sep{node{diag.Ranging{begin, end}, src[begin:end], nil, nil}}
+	return &Sep{node: node{diag.Ranging{From: begin, To: end}, src[begin:end], nil, nil}}
 }
 
 func (*Sep) parse(*parser) {
@@ -957,8 +960,7 @@ spaces:
 				}
 				ps.next()
 			}
-		case r == '\\' || r == '^':
-			p := ps.pos
+		case r == '^':
 			// Line continuation is like inline whitespace.
 			ps.next()
 			switch ps.peek() {
@@ -967,14 +969,8 @@ spaces:
 				if ps.peek() == '\n' {
 					ps.next()
 				}
-				if r == '\\' {
-					backslashLineCont(ps, p)
-				}
 			case '\n':
 				ps.next()
-				if r == '\\' {
-					backslashLineCont(ps, p)
-				}
 			case eof:
 				ps.error(errShouldBeNewline)
 			default:
@@ -988,20 +984,6 @@ spaces:
 	addSep(n, ps)
 }
 
-func backslashLineCont(ps *parser, p int) {
-	if !prog.ShowDeprecations || ps.warn == nil {
-		return
-	}
-	err := diag.Error{
-		Type:    "deprecation",
-		Message: "using \\ for line continuation is deprecated; use ^ instead",
-		Context: diag.Context{
-			Name: ps.srcName, Source: ps.src,
-			Ranging: diag.Ranging{From: p, To: p + 1}},
-	}
-	fmt.Fprintln(ps.warn, err.Show(""))
-}
-
 // IsInlineWhitespace reports whether r is an inline whitespace character.
 // Currently this includes space (Unicode 0x20) and tab (Unicode 0x9).
 func IsInlineWhitespace(r rune) bool {
