@@ -11,10 +11,8 @@ func TestSourceAsStructMap(t *testing.T) {
 	vals.TestValue(t, Source{Name: "[tty]", Code: "echo"}).
 		Kind("structmap").
 		Repr("[&name='[tty]' &code=<...> &is-file=$false]").
-		AllKeys("name", "code", "is-file", "path").
-		Index("path", "")
+		AllKeys("name", "code", "is-file")
 
 	vals.TestValue(t, Source{Name: "/etc/rc.elv", Code: "echo", IsFile: true}).
-		Index("is-file", true).
-		Index("path", "/etc/rc.elv")
+		Index("is-file", true)
 }
