@@ -6,14 +6,13 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/elves/elvish/pkg/util"
+	"github.com/elves/elvish/pkg/fsutil"
 )
 
 // Paths keeps all paths required for the Elvish runtime.
 type Paths struct {
-	RunDir          string
-	Sock            string
-	DaemonLogPrefix string
+	RunDir string
+	Sock   string
 
 	DataDir string
 	Db      string
@@ -29,7 +28,6 @@ func MakePaths(stderr io.Writer, overrides Paths) Paths {
 	setDir(&p.RunDir, "secure run directory", getSecureRunDir, stderr)
 	if p.RunDir != "" {
 		setChild(&p.Sock, p.RunDir, "sock")
-		setChild(&p.DaemonLogPrefix, p.RunDir, "daemon.log-")
 	}
 
 	setDir(&p.DataDir, "data directory", ensureDataDir, stderr)
@@ -71,7 +69,7 @@ func setChild(p *string, d, name string) {
 // the path to the data directory (never with a trailing slash) and possible
 // error.
 func ensureDataDir() (string, error) {
-	home, err := util.GetHome("")
+	home, err := fsutil.GetHome("")
 	if err != nil {
 		return "", err
 	}
