@@ -4,30 +4,31 @@ import (
 	"os"
 	"testing"
 
+	"github.com/elves/elvish/pkg/env"
 	. "github.com/elves/elvish/pkg/prog/progtest"
 )
 
 func TestShell_SHLVL_NormalCase(t *testing.T) {
-	restore := saveEnv("SHLVL")
+	restore := saveEnv(env.SHLVL)
 	defer restore()
 
-	os.Setenv("SHLVL", "10")
+	os.Setenv(env.SHLVL, "10")
 	testSHLVL(t, "11")
 }
 
 func TestShell_SHLVL_Unset(t *testing.T) {
-	restore := saveEnv("SHLVL")
+	restore := saveEnv(env.SHLVL)
 	defer restore()
 
-	os.Unsetenv("SHLVL")
+	os.Unsetenv(env.SHLVL)
 	testSHLVL(t, "1")
 }
 
 func TestShell_SHLVL_Invalid(t *testing.T) {
-	restore := saveEnv("SHLVL")
+	restore := saveEnv(env.SHLVL)
 	defer restore()
 
-	os.Setenv("SHLVL", "invalid")
+	os.Setenv(env.SHLVL, "invalid")
 	testSHLVL(t, "1")
 }
 
@@ -42,10 +43,10 @@ func TestShell_NegativeSHLVL_Increments(t *testing.T) {
 	// 1
 	//
 	// Elvish follows Zsh here.
-	restore := saveEnv("SHLVL")
+	restore := saveEnv(env.SHLVL)
 	defer restore()
 
-	os.Setenv("SHLVL", "-100")
+	os.Setenv(env.SHLVL, "-100")
 	testSHLVL(t, "-99")
 }
 
@@ -54,13 +55,14 @@ func testSHLVL(t *testing.T, wantSHLVL string) {
 	f := Setup()
 	defer f.Cleanup()
 
-	oldValue, oldOK := os.LookupEnv("SHLVL")
+	oldValue, oldOK := os.LookupEnv(env.SHLVL)
 
 	Script(f.Fds(), []string{"print $E:SHLVL"}, &ScriptConfig{Cmd: true})
 	f.TestOut(t, 1, wantSHLVL)
+	f.TestOut(t, 2, "")
 
 	// Test that state of SHLVL is restored.
-	newValue, newOK := os.LookupEnv("SHLVL")
+	newValue, newOK := os.LookupEnv(env.SHLVL)
 	if newValue != oldValue {
 		t.Errorf("SHLVL not restored, %q -> %q", oldValue, newValue)
 	}
